==> libreoffice-still-sdk-7.3.7-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/typedefs_9.js <==
var searchData=
[
  ['uno_5facquirefunc_0',['uno_AcquireFunc',['../a00272.html#ae005c271af398d0842fdeea3a95315a1',1,'data.h']]],
  ['uno_5facquiremappingfunc_1',['uno_AcquireMappingFunc',['../a00260.html#abff3fe0eeaae246cfcd6606b1cc492ae',1,'mapping.h']]],
  ['uno_5fany_2',['uno_Any',['../a00266.html#a61e69c4a6c0e459204403c1d5bb3b2e5',1,'any2.h']]],
  ['uno_5fdispatchmethod_3',['uno_DispatchMethod',['../a00284.html#aca3081fa5fa64b818fa97c8f0e24edf1',1,'dispatcher.h']]],
  ['uno_5fenterable_5fcallinto_5fv_4',['uno_Enterable_callInto_v',['../a00296.html#aa72e3a710031e48716221b05637da2d4',1,'Enterable.h']]],
  ['uno_5fenterable_5fcallout_5fv_5',['uno_Enterable_callOut_v',['../a00296.html#a6dc8ae3dfbc0cf9fae077b386d3741c6',1,'Enterable.h']]],
  ['uno_5fenterable_5fenter_6',['uno_Enterable_enter',['../a00296.html#a8a24a898cb8e9b36fc9e450a85bef380',1,'Enterable.h']]],
  ['uno_5fenterable_5fisvalid_5fv_7',['uno_Enterable_isValid_v',['../a00296.html#ab0a2639a88519e99402b5e98bb5dbf3b',1,'Enterable.h']]],
  ['uno_5fenterable_5fleave_8',['uno_Enterable_leave',['../a00296.html#a43424074f509960815ee7e5034b3a959',1,'Enterable.h']]],
  ['uno_5fenvcallee_9',['uno_EnvCallee',['../a00293.html#ab9b865bd93a54c6b944a0c2a7e56563b',1,'environment.h']]],
  ['uno_5fenvironment_10',['uno_Environment',['../a00293.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment():&#160;environment.h'],['../a00431.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment():&#160;factory.hxx']]],
  ['uno_5fext_5fgetmappingfunc_11',['uno_ext_getMappingFunc',['../a00260.html#acb7eed6ff94dfcaebc5d3c659a04726f',1,'mapping.h']]],
  ['uno_5fextenvironment_12',['uno_ExtEnvironment',['../a00293.html#a6b8ac7393f2c17002b1bb91c0be01c1b',1,'environment.h']]],
  ['uno_5ffreemappingfunc_13',['uno_freeMappingFunc',['../a00260.html#ae0198eda21db3f3ff5ac8ddb878d38c2',1,'mapping.h']]],
  ['uno_5ffreeproxyfunc_14',['uno_freeProxyFunc',['../a00293.html#a2ffa03a636a5dd3845056056a1dca05b',1,'environment.h']]],
  ['uno_5fgetmappingfunc_15',['uno_getMappingFunc',['../a00260.html#af7d3d95e35e4e1bab13a5af55cca4c42',1,'mapping.h']]],
  ['uno_5finitenvironmentfunc_16',['uno_initEnvironmentFunc',['../a00293.html#a65fa1b1ce1d750173fdeac329953240f',1,'environment.h']]],
  ['uno_5finterface_17',['uno_Interface',['../a00284.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface():&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface():&#160;mapping.hxx']]],
  ['uno_5fmapinterfacefunc_18',['uno_MapInterfaceFunc',['../a00260.html#aa7d6cb720868db0b34be2d06e84b52c6',1,'mapping.h']]],
  ['uno_5fmapping_19',['uno_Mapping',['../a00260.html#abe84c421515210d4c58d23656bf77a6e',1,'mapping.h']]],
  ['uno_5fmemalloc_20',['uno_memAlloc',['../a00293.html#a601137e3ecc972111d489346f3d72325',1,'environment.h']]],
  ['uno_5fqueryinterfacefunc_21',['uno_QueryInterfaceFunc',['../a00272.html#adf2a74e519b6ea095ff4653b27754a7a',1,'data.h']]],
  ['uno_5freleasefunc_22',['uno_ReleaseFunc',['../a00272.html#a55022adf86896f1a0ff9f78eb14afc22',1,'data.h']]],
  ['uno_5freleasemappingfunc_23',['uno_ReleaseMappingFunc',['../a00260.html#a5a7bfe92bc21c7dec6f490fe427838de',1,'mapping.h']]],
  ['uno_5fsequence_24',['uno_Sequence',['../a00299.html#a4311404b36f401ba2fa39f246c91375a',1,'sequence2.h']]],
  ['uno_5fthreadpool_25',['uno_ThreadPool',['../a00302.html#a652117a32126083087ed23fb7c76439d',1,'threadpool.h']]]
];

==> libreoffice-still-sdk-7.5.7-3-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/typedefs_9.js <==
var searchData=
[
  ['uno_5facquirefunc_0',['uno_AcquireFunc',['../a00272.html#ae005c271af398d0842fdeea3a95315a1',1,'data.h']]],
  ['uno_5facquiremappingfunc_1',['uno_AcquireMappingFunc',['../a00260.html#abff3fe0eeaae246cfcd6606b1cc492ae',1,'mapping.h']]],
  ['uno_5fany_2',['uno_Any',['../a00266.html#a61e69c4a6c0e459204403c1d5bb3b2e5',1,'any2.h']]],
  ['uno_5fdispatchmethod_3',['uno_DispatchMethod',['../a00284.html#aca3081fa5fa64b818fa97c8f0e24edf1',1,'dispatcher.h']]],
  ['uno_5fenterable_5fcallinto_5fv_4',['uno_Enterable_callInto_v',['../a00296.html#aa72e3a710031e48716221b05637da2d4',1,'Enterable.h']]],
  ['uno_5fenterable_5fcallout_5fv_5',['uno_Enterable_callOut_v',['../a00296.html#a6dc8ae3dfbc0cf9fae077b386d3741c6',1,'Enterable.h']]],
  ['uno_5fenterable_5fenter_6',['uno_Enterable_enter',['../a00296.html#a8a24a898cb8e9b36fc9e450a85bef380',1,'Enterable.h']]],
  ['uno_5fenterable_5fisvalid_5fv_7',['uno_Enterable_isValid_v',['../a00296.html#ab0a2639a88519e99402b5e98bb5dbf3b',1,'Enterable.h']]],
  ['uno_5fenterable_5fleave_8',['uno_Enterable_leave',['../a00296.html#a43424074f509960815ee7e5034b3a959',1,'Enterable.h']]],
  ['uno_5fenvcallee_9',['uno_EnvCallee',['../a00293.html#ab9b865bd93a54c6b944a0c2a7e56563b',1,'environment.h']]],
  ['uno_5fenvironment_10',['uno_environment',['../a00293.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment:&#160;environment.h'],['../a00431.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment:&#160;factory.hxx']]],
  ['uno_5fext_5fgetmappingfunc_11',['uno_ext_getMappingFunc',['../a00260.html#acb7eed6ff94dfcaebc5d3c659a04726f',1,'mapping.h']]],
  ['uno_5fextenvironment_12',['uno_ExtEnvironment',['../a00293.html#a6b8ac7393f2c17002b1bb91c0be01c1b',1,'environment.h']]],
  ['uno_5ffreemappingfunc_13',['uno_freeMappingFunc',['../a00260.html#ae0198eda21db3f3ff5ac8ddb878d38c2',1,'mapping.h']]],
  ['uno_5ffreeproxyfunc_14',['uno_freeProxyFunc',['../a00293.html#a2ffa03a636a5dd3845056056a1dca05b',1,'environment.h']]],
  ['uno_5fgetmappingfunc_15',['uno_getMappingFunc',['../a00260.html#af7d3d95e35e4e1bab13a5af55cca4c42',1,'mapping.h']]],
  ['uno_5finitenvironmentfunc_16',['uno_initEnvironmentFunc',['../a00293.html#a65fa1b1ce1d750173fdeac329953240f',1,'environment.h']]],
  ['uno_5finterface_17',['uno_interface',['../a00284.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface:&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface:&#160;mapping.hxx']]],
  ['uno_5fmapinterfacefunc_18',['uno_MapInterfaceFunc',['../a00260.html#aa7d6cb720868db0b34be2d06e84b52c6',1,'mapping.h']]],
  ['uno_5fmapping_19',['uno_Mapping',['../a00260.html#abe84c421515210d4c58d23656bf77a6e',1,'mapping.h']]],
  ['uno_5fmemalloc_20',['uno_memAlloc',['../a00293.html#a601137e3ecc972111d489346f3d72325',1,'environment.h']]],
  ['uno_5fqueryinterfacefunc_21',['uno_QueryInterfaceFunc',['../a00272.html#adf2a74e519b6ea095ff4653b27754a7a',1,'data.h']]],
  ['uno_5freleasefunc_22',['uno_ReleaseFunc',['../a00272.html#a55022adf86896f1a0ff9f78eb14afc22',1,'data.h']]],
  ['uno_5freleasemappingfunc_23',['uno_ReleaseMappingFunc',['../a00260.html#a5a7bfe92bc21c7dec6f490fe427838de',1,'mapping.h']]],
  ['uno_5fsequence_24',['uno_Sequence',['../a00299.html#a4311404b36f401ba2fa39f246c91375a',1,'sequence2.h']]],
  ['uno_5fthreadpool_25',['uno_ThreadPool',['../a00302.html#a652117a32126083087ed23fb7c76439d',1,'threadpool.h']]]
];
